@@ -9,7 +9,7 @@ import requests
 import json
 import os
 import logging
-from anaplan_api import anaplan_auth
+from anaplan_api import anaplan_cert_auth, anaplan_basic_auth
 from time import sleep
 from requests.exceptions import HTTPError
 
@@ -23,23 +23,7 @@ __post_body__ = {
 __BYTES__ = 1024 * 1024
 __chunk__ = 0
 
-logger = logging.getLogger
-
-#===========================================================================
-# This function sets the log level for the library.
-#===========================================================================
-def create_logger(level):
-    '''
-    :param level: Log level to report
-    :param *args: If not null, path to file save logs.
-    '''
-    logging.basicConfig(format='%(asctime)s,%(msecs)d %(name)s %(levelname)s %(message)s',
-                        datefmt='%H:%M:%S',
-                        level=level)
-    logger = logging.getLogger("AnaplanPythonAPI")
-    
-    return logger
-    
+logger = logging.getLogger(__name__)
 
 #===========================================================================
 # This function reads the authentication type, Basic or Certificate, then passes
@@ -50,28 +34,24 @@ def generate_authorization(auth_type, *args):
     :param auth_type: 
     :param *args: Path to public certificate, and private key if auth_type='certificate'; Anaplan Username, Anaplan 
                   Password, and private key if auth_type='basic'
+    :returns: Header Authenication value, and token expiry in epoch
     '''
     
-    anaplan_auth.logger = logger
-        
     if auth_type.lower() == 'basic':
-        header_string = anaplan_auth.basic_auth_header(args[0], args[1])
-        
-        authorization = anaplan_auth.authenticate(anaplan_auth.auth_request(header_string, body=None))
+        header_string = anaplan_basic_auth.auth_header(args[0], args[1])
+        authorization = anaplan_basic_auth.authenticate(anaplan_basic_auth.auth_request(header_string))
         return authorization
     elif auth_type.lower() == 'certificate':
         privKey = args[0]
         pubCert = args[1]
         
-        header_string = anaplan_auth.certificate_auth_header(pubCert)
-        post_data = anaplan_auth.generate_post_data(privKey)
-        
-        authorization = anaplan_auth.authenticate(anaplan_auth.auth_request(header_string, post_data))
+        header_string = anaplan_cert_auth.auth_header(pubCert)
+        post_data = anaplan_cert_auth.generate_post_data(privKey)
+        authorization = anaplan_cert_auth.authenticate(anaplan_cert_auth.auth_request(header_string, post_data))
         if not authorization[:5] == "Error":
             return authorization   
         else:
             logger.error("Authentication Failed: %s", authorization)
-            #print("Authentication Failed: " + authorization) 
     else:
         logger.error("Please enter a valid authentication method: Basic or Certificate")
 
@@ -145,7 +125,7 @@ def flat_file_upload(conn, fileId, chunkSize, file):
                     except HTTPError as e:
                         raise HTTPError(e)
                     logger.debug("Chunk %s uploaded successfully.", str(chunkNum + 1))
-                    #print("Chunk " + str(chunkNum + 1) +" uploaded, Status: " + str(file_upload.status_code))
+
                     if not file_upload.ok:
                         complete = False #If the upload fails, break the loop and prevent subsequent requests. Print error to screen
                         logger.error("Error %s\n%s", str(file_upload.status_code), file_upload.text)
@@ -210,12 +190,10 @@ def stream_upload(conn, file_id, buffer, **args):
             logger.debug("%s chunk(s) successfully uploaded to Anaplan.", __chunk__)
         else:
             logger.error("There was an error completing your upload: %s \n %s", complete_upload.status_code, complete_upload.text)
-            #return "There was an error completing your upload: " + complete_upload.status_code + '\n' + complete_upload.text     
         __chunk__ = 0
     else:
         if(len(buffer.encode()) > (__BYTES__ * 50)):
             logger.error("Buffer too large, please send less than 50mb of data.")
-            #return "Buffer too large, please send less than 50mb of data."
         else:
             if __chunk__ == 0:    
                 logger.info("Starting file upload...")    
@@ -227,18 +205,15 @@ def stream_upload(conn, file_id, buffer, **args):
             #Confirm that the metadata update for the requested file was OK before proceeding with file upload
             try:
                 logger.debug("Attempting to upload chunk %s...", (str(__chunk__ + 1)))
-                stream_upload = requests.put(url + "/chunks/" + str(__chunk__), headers=put_header, data=buffer)
+                stream_upload = requests.put(url + "/chunks/" + str(__chunk__), headers=put_header, data=buffer.encode('utf-8'))
                 stream_upload.raise_for_status()
             except HTTPError() as e:
                 raise HTTPError(e)
             if not stream_upload.ok:
                 logger.error("Error %s\n%s", str(stream_upload.status_code), stream_upload.text)
-                #return "Error " + str(stream_upload.status_code) + '\n' + stream_upload.text
             else:
                 __chunk__ += 1
                 logger.debug("Successfully uploaded chunk number %s", str(__chunk__))
-                #return "Uploaded chunk " + str(__chunk__) + ", Status: " + str(stream_upload.status_code)
-            
 
 #===========================================================================
 # This function reads the ID of the desired action to run, POSTs the task
@@ -441,8 +416,6 @@ def parse_task_response(results, url, taskId, post_header):
     if job_status == "Failed.":
         error_message = str(results["result"]["details"][0]["localMessageText"])
         logger.error("The task has failed to run due to an error: %s", error_message)
-        #print("The task has failed to run due to an error: " + error_message)
-        #return "The task has failed to run due to an error: " + error_message
     else:
         if failure_alert == "True":
             try:
@@ -470,20 +443,16 @@ def parse_task_response(results, url, taskId, post_header):
                             dump = requests.get(url + "/" + taskId + '/' + "dumps" + '/' + object_id,  headers=post_header)
                             dump.raise_for_status()
                         except HTTPError as e:
-                            raise HTTPError(e)
+                            logger.error(e)
                         report = "Error dump for " + object_id + '\n' + dump.text
                         anaplan_process_dump += report  
-                        failure_details = failure_details + local_message      
+                        failure_details = failure_details + local_message
             if anaplan_process_dump != "":
                 logger.info("The requested job is %s", job_status)
-                #print("The requested job is " + job_status)
                 logger.info("%s\nDeails:\n%s\nFailure dump(s):\n%s", load_detail, error_detail, anaplan_process_dump)
-                #return load_detail + '\n' + "Details:" + '\n' + error_detail + '\n' + "Failure dump(s):" + '\n' + anaplan_process_dump
             else:
                 logger.info("The requested job is %s", job_status)
-                #print("The requested job is " + job_status)
                 logger.info(load_detail)
-                #return load_detail
         else:
             if "details" in results["result"]:
                 if str(results["result"]["details"][0]["type"]) == "exportSucceeded":
@@ -497,15 +466,10 @@ def parse_task_response(results, url, taskId, post_header):
                         load_detail = load_detail + i + '\n'
                     if failure_alert == "True":
                         logger.info("The requested job is %s", job_status)
-                        #print("The requested job is " + job_status)
                         logger.error("Failure Dump Available: %s, Successful: %s\nLoad details:\n%s\n%s\nFailure dump:\n%s", failure_alert, success_report, load, load_detail, dump)
-                        #return "Failure Dump Available: " + failure_alert + ", Successful: " + success_report + '\n' + "Load details:" + '\n' + load + '\n' + load_detail + '\n' + "Failure dump:" + '\n' + dump
                     else:
                         logger.info("The requested job is %s", job_status)
-                        #print("The requested job is " + job_status)
                         logger.error("Failure Dump Available: %s, Successful: %s\nLoad details:\n%s\n%s", failure_alert, success_report, load, load_detail)
-                        #return "Failure Dump Available: " + failure_alert + ", Successful: " + success_report + '\n' + "Load details:" + '\n' + load + '\n' + load_detail
-                
 
 #===========================================================================
 # This function queries the Anaplan model for a list of the desired resources:
@@ -528,7 +492,6 @@ def get_list(conn, resource):
     url = __base_url__ + "/" + workspaceGuid + "/models/" + modelGuid + "/" + resource.lower()
     
     logger.debug("Fetching %s", resource)
-    #print("Fetching " + resource + "...")
     
     try:
         response = requests.get(url, headers=get_header)
@@ -539,7 +502,6 @@ def get_list(conn, resource):
     response = json.loads(response)
     
     logger.debug("Finished fetching %s", resource)
-    #print("Finished fetching " + resource + ".")
      
     return response[resource]
 
@@ -556,7 +518,6 @@ def parse_get_response(response):
             break
         else:
             logger.info("Name: %s\nID: %s\n", item["name"], item["id"])
-            #print("Name: " + item["name"] + '\n' + "ID: " + item["id"] + '\n')
             
 #===========================================================================
 # This function downloads a file from Anaplan to the specified path.
@@ -599,13 +560,11 @@ def get_file(conn, fileId):
             file += file_contents.text
         else:
             logger.error("There was a problem downloading %s", file_name)
-            #return "There was a problem fetching the file: " + file_name
             break
         chunk = str(int(chunk) + 1)
         
     if int(chunk) == int(chunk_count):
         logger.info("File download complete!")
-        #print("File download complete!")
         
     return file        
 
@@ -726,7 +685,6 @@ def get_models(conn, user_id):
         logger.error("Error loading models list: %s", e)
     
     logger.debug("Finished fetching models.")
-    #print("Finished fetching models.")
     
     return model_list
 
@@ -750,7 +708,6 @@ def get_workspaces(conn, user_id):
                 }
     
     logger.debug("Fetching workspaces.")
-    #print("Fetching workspaces...")
     
     try:
         workspace_list=requests.get(url, headers=get_header)
@@ -767,6 +724,5 @@ def get_workspaces(conn, user_id):
         logger.error("Error locating workspace list: %s", e)
     
     logger.debug("Finished fetching workspaces.")
-    #print("Finished fetching workspaces.")
     
     return model_list
\ No newline at end of file
